#
# spec file for package pam_p11
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pam_p11
Version:        0.5.0
Release:        1.3
Summary:        PAM Authentication Module for Using Cryptographic Tokens
License:        LGPL-2.1-or-later
Group:          Hardware/Other
URL:            https://github.com/OpenSC/pam_p11
Source0:        %{url}/releases/download/pam_p11-%{version}/pam_p11-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  libp11-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel

%description
Pam_p11 is a pluggable authentication module (pam) package for using
cryptographic tokens, such as smart cards and usb crypto tokens, for
authentication.

Pam_p11 has limited functionality since it simply compares public
keys to sign some random data and verifies the signature with the
public key. This works fine for small installations but may have
security implications, see README.SUSE.

%prep
%setup -q

%build
CFLAGS="%optflags -Wno-error=deprecated-declarations"
%configure\
	--with-pamdir=/%{_pam_moduledir} \
	--disable-static \
	--docdir=%{_docdir}/%{name}

make %{?_smp_mflags}

%install
%make_install
# remove .la files
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{name}.mo

%files -f %{name}.mo
%license COPYING
%doc README.md NEWS
/%{_pam_moduledir}/*.so

%changelog
* Tue Aug 29 2023 Otto Hollmann <otto.hollmann@suse.com>
- Update to version 0.5.0
  * Add support for tokens that only contain a certificate
    (and no public key)
  * Fixed never-ending loop if the PIN is locked
- Update to version 0.4.0
  * Add Russian translation
  * Add support for building with LibreSSL
  * Add support for building with OpenSSL 3.0 and later
* Wed Feb 15 2023 Marcus Meissner <meissner@suse.com>
- disabled error on deprecated for now, to make it build with openssl-3
* Fri Jul 29 2022 pgajdos@suse.com
- use pam rpm macros [bsc#1190955]
* Mon May 17 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.3.1
  * CVE-2019-16058: Fixed buffer overflow when creating signatures
    longer than 256 bytes
- Drop upstream fixed pam_p11-0.3.0-lto-type-mismatch.patch
* Sat Aug 10 2019 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 0.3.0:
  * Add Italian translation.
  * Add support for matching the PIN-input with a regular
    expression.
  * Add support for macOS
  * Add support for building with OpenSSL 1.1.1
  * Add support for nistp256/384/521 keys in authorized_keys file.
- Remove README.SUSE: Its content is present in README.md which
  is now installed.
- Add pam_p11-0.3.0-lto-type-mismatch.patch: Fix build with LTO on
  x86_64.
- Drop upstreamed patches:
  * pam_p11-replace-deprecated-OpenSSL-API-functions.patch
  * pam_p11-unsigned-comparison.patch
* Thu Jan 31 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update to version 0.2.0 [bsc#1123392, bsc#1123916]
  * Add user documentation in Readme.md
  * Add support for PIN pad readers
  * Add support for changing/unblocking PIN (use with passwd)
  * Add support for localized user feedback
  * Add support for cards without certificates (e.g. OpenPGP card)
  * Add support for PKCS#11 modules with multiple slots
  * Add support for building with OpenSSL 1.1
  * Merged opensc and openssh module into pam_p11.so
  * Fixed memory leaks, coverity issues, compiler warnings
  * Created test-passwd and test-login for testing standard use cases
- Added patch to replace deprecated EVP_MD_CTX_cleanup(md_ctx) with
  EVP_MD_CTX_reset(md_ctx)
  * pam_p11-replace-deprecated-OpenSSL-API-functions.patch
- Added patch to fix unsigned comparison
  * pam_p11-unsigned-comparison.patch
- Removed patch fixed upstream:
  * pam_p11-openssl11.patch
- Mark locale-dependent file:
  /usr/share/locale/de/LC_MESSAGES/pam_p11.mo
- Added documentation file README.SUSE with a Security Note
- Cleaned with spec-cleaner
* Mon Jan 22 2018 vcizek@suse.com
- Update to version 0.1.6
  * Build system rewritten (NOTICE: configure options was modified).
- shorten the Description, fixes "invalid utf-8 encoding in Description"
- fix build with openssl 1.1 (bsc#1074800)
  * add pam_p11-openssl11.patch
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Thu Jun 25 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Wed Sep 10 2008 sbrabec@suse.cz
- Updated to version 0.1.5:
  * fix wiki to html export.
  * number of build fixes
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Jul 26 2007 sbrabec@suse.cz
- Updated to version 0.1.3:
  * make some functions static.
  * rename variables to avoid names of glibc functions
    (e.g. random).
  * do not save the password (i.e. pin - shouldn't go anywhere
    except to the card).
* Thu Mar 29 2007 ro@suse.de
- added zlib-devel to buildreq
* Fri May 12 2006 sbrabec@suse.cz
- New SuSE package, version 0.1.2.
